Documentation
¶
Overview ¶
Code generated by protoc-gen-go-pulsar. DO NOT EDIT.
Index ¶
- Variables
- type GeneratorParams
- func (*GeneratorParams) Descriptor() ([]byte, []int)deprecated
- func (x *GeneratorParams) GetBucketCount() uint64
- func (x *GeneratorParams) GetDeleteWeight() float32
- func (x *GeneratorParams) GetGenesisCount() uint64
- func (x *GeneratorParams) GetGetWeight() float32
- func (x *GeneratorParams) GetInsertWeight() float32
- func (x *GeneratorParams) GetKeyMean() uint64
- func (x *GeneratorParams) GetKeyStdDev() uint64
- func (x *GeneratorParams) GetSeed() uint64
- func (x *GeneratorParams) GetUpdateWeight() float32
- func (x *GeneratorParams) GetValueMean() uint64
- func (x *GeneratorParams) GetValueStdDev() uint64
- func (*GeneratorParams) ProtoMessage()
- func (x *GeneratorParams) ProtoReflect() protoreflect.Message
- func (x *GeneratorParams) Reset()
- func (x *GeneratorParams) String() string
- type Module
Constants ¶
This section is empty.
Variables ¶
var File_cosmos_benchmark_module_v1_module_proto protoreflect.FileDescriptor
Functions ¶
This section is empty.
Types ¶
type GeneratorParams ¶
type GeneratorParams struct {
// seed is the seed for the random number generator.
Seed uint64 `protobuf:"varint,1,opt,name=seed,proto3" json:"seed,omitempty"`
// bucket_count is the number of store keys to uniformly distribute genesis_count keys across.
BucketCount uint64 `protobuf:"varint,2,opt,name=bucket_count,json=bucketCount,proto3" json:"bucket_count,omitempty"`
// key_mean is the mean size (in normal distribution) of keys in each bucket.
KeyMean uint64 `protobuf:"varint,3,opt,name=key_mean,json=keyMean,proto3" json:"key_mean,omitempty"`
// key_std_dev is the standard deviation of key sizes in each bucket.
KeyStdDev uint64 `protobuf:"varint,4,opt,name=key_std_dev,json=keyStdDev,proto3" json:"key_std_dev,omitempty"`
// value_mean is the mean size (in normal distribution) of values in each bucket.
ValueMean uint64 `protobuf:"varint,6,opt,name=value_mean,json=valueMean,proto3" json:"value_mean,omitempty"`
// value_std_dev is the standard deviation of value sizes in each bucket.
ValueStdDev uint64 `protobuf:"varint,7,opt,name=value_std_dev,json=valueStdDev,proto3" json:"value_std_dev,omitempty"`
// genesis_count is the number of keys to insert in the store, distributed across all buckets.
GenesisCount uint64 `protobuf:"varint,8,opt,name=genesis_count,json=genesisCount,proto3" json:"genesis_count,omitempty"`
// insert_weight is the weight of insert operations.
InsertWeight float32 `protobuf:"fixed32,9,opt,name=insert_weight,json=insertWeight,proto3" json:"insert_weight,omitempty"`
// update_weight is the weight of update operations.
UpdateWeight float32 `protobuf:"fixed32,10,opt,name=update_weight,json=updateWeight,proto3" json:"update_weight,omitempty"`
// get_weight is the weight of get operations.
GetWeight float32 `protobuf:"fixed32,12,opt,name=get_weight,json=getWeight,proto3" json:"get_weight,omitempty"`
// delete_weight is the weight of delete operations.
DeleteWeight float32 `protobuf:"fixed32,11,opt,name=delete_weight,json=deleteWeight,proto3" json:"delete_weight,omitempty"`
// contains filtered or unexported fields
}
GenesisParams defines the genesis parameters for the benchmark module.
func (*GeneratorParams) Descriptor
deprecated
func (*GeneratorParams) Descriptor() ([]byte, []int)
Deprecated: Use GeneratorParams.ProtoReflect.Descriptor instead.
func (*GeneratorParams) GetBucketCount ¶
func (x *GeneratorParams) GetBucketCount() uint64
func (*GeneratorParams) GetDeleteWeight ¶
func (x *GeneratorParams) GetDeleteWeight() float32
func (*GeneratorParams) GetGenesisCount ¶
func (x *GeneratorParams) GetGenesisCount() uint64
func (*GeneratorParams) GetGetWeight ¶
func (x *GeneratorParams) GetGetWeight() float32
func (*GeneratorParams) GetInsertWeight ¶
func (x *GeneratorParams) GetInsertWeight() float32
func (*GeneratorParams) GetKeyMean ¶
func (x *GeneratorParams) GetKeyMean() uint64
func (*GeneratorParams) GetKeyStdDev ¶
func (x *GeneratorParams) GetKeyStdDev() uint64
func (*GeneratorParams) GetSeed ¶
func (x *GeneratorParams) GetSeed() uint64
func (*GeneratorParams) GetUpdateWeight ¶
func (x *GeneratorParams) GetUpdateWeight() float32
func (*GeneratorParams) GetValueMean ¶
func (x *GeneratorParams) GetValueMean() uint64
func (*GeneratorParams) GetValueStdDev ¶
func (x *GeneratorParams) GetValueStdDev() uint64
func (*GeneratorParams) ProtoMessage ¶
func (*GeneratorParams) ProtoMessage()
func (*GeneratorParams) ProtoReflect ¶
func (x *GeneratorParams) ProtoReflect() protoreflect.Message
func (*GeneratorParams) Reset ¶
func (x *GeneratorParams) Reset()
func (*GeneratorParams) String ¶
func (x *GeneratorParams) String() string
type Module ¶
type Module struct {
GenesisParams *GeneratorParams `protobuf:"bytes,1,opt,name=genesis_params,json=genesisParams,proto3" json:"genesis_params,omitempty"`
// contains filtered or unexported fields
}
Module is the config object of the benchmark module.
func (*Module) Descriptor
deprecated
func (*Module) GetGenesisParams ¶
func (x *Module) GetGenesisParams() *GeneratorParams
func (*Module) ProtoMessage ¶
func (*Module) ProtoMessage()
func (*Module) ProtoReflect ¶
func (x *Module) ProtoReflect() protoreflect.Message
Click to show internal directories.
Click to hide internal directories.